import envyaml
import os
import logging
from logging import Formatter, StreamHandler
import weaviate
import json

config = envyaml.EnvYAML(os.environ.get('CONFIG_PATH', 'config.yaml'))

def initLogger() -> None:
    """
    Initializes the logger
    """
    # style the logger output to look like uvicorn for root app
    FORMAT = '%(asctime)-15s %(levelname)s %(message)s'
    DATE_FORMAT = '%b %d %H:%M:%S'
    formatter = Formatter(fmt=FORMAT, datefmt=DATE_FORMAT)
    handler = StreamHandler()
    handler.setFormatter(formatter)
    logger = logging.getLogger()

    # remove default handler
    logger.handlers = []
    logger.addHandler(handler)

    if config["app.log.level"] == 'debug':
        logging.basicConfig(level=logging.DEBUG)
    elif config["app.log.level"] == 'info':
        logging.basicConfig(level=logging.INFO)
    elif config["app.log.level"] == 'warning':
        logging.basicConfig(level=logging.WARNING)
    elif config["app.log.level"] == 'error':
        logging.basicConfig(level=logging.ERROR)
    elif config["app.log.level"] == 'critical':
        logging.basicConfig(level=logging.CRITICAL)
    else:
        logging.basicConfig(level=logging.INFO)
        logging.warning("Invalid log level. Using INFO as default")

def initEnvironment() -> None:
    os.environ["OPENAI_PROXY"] = config["app.openai.url"]
    os.environ["OPENAI_API_KEY"] = config["app.openai.api_key"]

def initWeviate() -> None:
    logging.debug("Initializing Weaviate")
    client = weaviate.Client(config["app.weaviate.url"])
    with open(config["app.weaviate.schema-path"]) as file:
        schema = json.load(file)
        if not client.schema.contains(schema):
            logging.debug("Creating Weaviate schema")
            client.schema.create(schema)
